@@ -1,8 +1,8 @@
 import datetime
 import time
-import pandas as pd
 
-from tqdm import trange
+# import pandas as pd
+# from tqdm import trange
 
 from src.web3_premium.explorer import snowtrace
 from src.web3_premium.contract import Contract
